==> dcp-client-0.36.0-sources.jar: com/couchbase/client/dcp/DataEventHandler.java <==
/*
 * Copyright (c) 2016 Couchbase, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.couchbase.client.dcp;

import com.couchbase.client.dcp.transport.netty.ChannelFlowController;
import com.couchbase.client.dcp.deps.io.netty.buffer.ByteBuf;

/**
 * This interface acts as a callback on the {@link Client#dataEventHandler(DataEventHandler)} API
 * that allows one to react to data events.
 * <p>
 * Right now {@link com.couchbase.client.dcp.message.DcpMutationMessage},
 * {@link com.couchbase.client.dcp.message.DcpExpirationMessage} and
 * {@link com.couchbase.client.dcp.message.DcpDeletionMessage} are emitted, but the expirations are
 * as of Couchbase Server 4.5.0 not actually emitted. So while good practice to handle them, even if
 * you opt out to do so make sure to release the buffers.
 * <p>
 * Keep in mind that the callback is called on the IO event loops, so you should never block or run
 * expensive computations in the callback! Use queues and other synchronization primities!
 *
 * @author Michael Nitschinger
 * @since 1.0.0
 */
public interface DataEventHandler {

  /**
   * Called when a data event happens.
   * <p>
   * Make sure to release the buffers!!
   *
   * @param flowController the flow controller for the passed event.
   * @param event the data event happening right now.
   */
  void onEvent(ChannelFlowController flowController, ByteBuf event);

}

==> dcp-client-0.44.0-sources.jar: com/couchbase/client/dcp/DataEventHandler.java <==
/*
 * Copyright (c) 2016 Couchbase, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.couchbase.client.dcp;

import com.couchbase.client.core.deps.io.netty.buffer.ByteBuf;
import com.couchbase.client.dcp.transport.netty.ChannelFlowController;

/**
 * This interface acts as a callback on the {@link Client#dataEventHandler(DataEventHandler)} API
 * that allows one to react to data events.
 * <p>
 * Right now {@link com.couchbase.client.dcp.message.DcpMutationMessage},
 * {@link com.couchbase.client.dcp.message.DcpExpirationMessage} and
 * {@link com.couchbase.client.dcp.message.DcpDeletionMessage} are emitted, but the expirations are
 * as of Couchbase Server 4.5.0 not actually emitted. So while good practice to handle them, even if
 * you opt out to do so make sure to release the buffers.
 * <p>
 * Keep in mind that the callback is called on the IO event loops, so you should never block or run
 * expensive computations in the callback! Use queues and other synchronization primities!
 *
 * @author Michael Nitschinger
 * @since 1.0.0
 */
public interface DataEventHandler {

  /**
   * Called when a data event happens.
   * <p>
   * Make sure to release the buffers!!
   *
   * @param flowController the flow controller for the passed event.
   * @param event the data event happening right now.
   */
  void onEvent(ChannelFlowController flowController, ByteBuf event);

}
